/*
 *--- PKeywords.h ---------------------------------------------------------
 * Copyright (c) 1995-96 Adobe Systems Incorporated.  All rights reserved.
 * Created on Sun, Oct 22, 1995 @ 4:49 PM by Paul Ferguson.
 *
 * Description: This file contains enums used by a variety
 * of classes for constructor parameters.  For constants
 * that apply only to a single command, the enum can be found
 * in the header file for that class.
 *-------------------------------------------------------------------------
 */
#ifndef __PKeywords__
#define __PKeywords__

#ifdef __MWERKS__
#pragma once
#endif

enum
{
	kParmDefault = -1,		// use default... whatever that happens to be
	kParmDontCare = -2,		// I don't care about this, leave it alone, or does not apply
	kParmNone = 0,
	kParmNormal = 0,
	
	kParmLeft = 0,
	kParmCenter,
	kParmRight,
	kParmTop,
	kParmBottom,

	kParmHorizontal = 1,
	kParmVertical = 2
};

typedef enum
{
	kAlignmentLeft = 0, 		// alignment for PAlignment and PTabs
	kAlignmentCenter,
	kAlignmentRight,
	kAlignmentJustify,
	kAlignmentForce,
	kAlignmentDecimal = 3
} eAlign;

typedef enum
{
	kAutoNone = 0, 		// auto renumbering mode for Book
	kAutoNext,
	kAutoNextOdd,
	kAutoNextEven
}eAuto;


typedef enum
{
	kBumpUpOne = 0, 		// bump text size for PSizeBump
	kBumpDownOne,
	kBumpUpNext,
	kBumpDownNext
} eBump;


typedef enum
{
	kCaseNormal = 0, 		// type case for PCase
	kCaseAllcaps,
	kCaseSmallcaps
	// kCaseMultiple = -2		// may be returned by PGetCase
} eCase;

typedef enum
{
	kCloseStoryDiscard,
	kCloseStoryPlace
} eCloseStory;

typedef enum
{
	kColorRGB = 0, 				// color models for DefineColor
	kColorCMYK,
	kColorHLS,
	kColorPantone, 				// obsolete
	kColorLab,
	kColorMultiInk,
	kColorRGB255				// Starting w/ 6.0, RGB colors are now spec'd
} eColor;						// as 0 to 255, as opposed to 0 to 100%. color_rgb
								// is used for 0 to 100% backward compatibility.
								// color_rgb255 is used for new 0 to 255 scale.

typedef enum
{
	kColorTypeSpot = 0, 		// color types for DefineColor
	kColorTypeProcess,
	kColorTypeTint,
	kColorTypeHifi
} eColorType;

typedef enum
{
	kColumnBothPages = 0, 	// pages for PColumnGuides and PMoveColumn
	kColumnLeftPage,
	kColumnRightPage
} eColumn;

typedef enum
{
	kCopyNone = 0, 				// copy files for SaveAs
	kCopyremote,
	kCopylinked
} eCopy;

typedef enum
{
	kDownloadPSandTT = 1,		// Option for printoptionsps command
	kDownloadTTonly = 2			// Option for printoptionsps command
} eDownload;

typedef enum
{
	kEdgeLeft = 0,			// object edges for various commands
	kEdgeCenter,
	kEdgeRight,
	kEdgeTop,
	kEdgeBottom,
	kEdgeLeftTop,
	kEdgeLeftBottom,
	kEdgeRightTop,
	kEdgeRightBottom
} eEdge;

typedef enum
{
	kEnvFontMetrics = 1, 		// bit flags for ChangeEnv
	kEnvInstalledFonts = 2,
	kEnvAdditions = 4,
	kEnvPlugins = 4
} eEnv;

typedef enum
{
	kFCSSelectedText = 0, 		// for find, change, spell commands
	kFCSCurrentStory = 1,
	kFCSAllStories = 2,
	kFCSStopAtEnd = 0,
	kFCSWrap = 1,
	kFCSWindowClose = 0,
	kFCSWindowOpen = 1
} eFCS;

typedef enum
{
	kFCAnyCase = 0,		// for find and change commands
	kFCMatchCase = 1,
	kFCAllInstances = 0,
	kFCWholeWord = 1,
	kFCUseAttributes = 0,
	kFCClear = 1
} eFC;

typedef enum
{
	kFCAttrAny = -3, 		// for PFindAttr and PChangeAttr commands
	kFCAttrNormalStyle = 0,
	kFCAttrBoldStyle = 1,
	kFCAttrItalicStyle = 2,
	kFCAttrUnderlineStyle = 4,
	kFCAttrStrikethruStyle = 8,
	kFCAttrOutlineStyle = 16,
	kFCAttrShadowStyle = 32,
	kFCAttrReverseStyle = 64,
	kFCAttrAllCap = 1,
	kFCAttrSmallCap = 2
} eFCAttr;

typedef enum
{
	kFillNone = 0, 		// fill style for PFillStyle
	kFillPaper,
	kFillSolid,
	kFillTenPct,
	kFillTwentyPct,
	kFillThirtyPct,
	kFillFortyPct,
	kFillSixtyPcT,
	kFillEightyPct,
	kFillVertFew,
	kFillVertLots,
	kFillHorizFew,
	kFillHorizLots,
	kFillDiagFew,
	kFillDiagLots,
	kFillHashFew,
	kFillHashLots
} eFillStyle;


typedef enum
{
	kFlowBreak = 0, 			// text flow for PTextWrap
	kFlowJumpOver,
	kFlowAllSides
} eFlow;

enum
{
	kGraphicsDisplayGray = 0, 	// graphic display preferences
	kGraphicsDisplayNormal = 1,
	kGraphicsDisplayHighres = 2
};

typedef enum
{
	kGuidesFront = 0, 			// guide layer preference
	kGuidesBack = 1
} eGuides;

typedef enum
{
	kHyphManualOnly = 1, 		// method for Hyphenation
	kHyphPlusDictionary,
	kHyphPlusAlgorithm
} eHyph;

typedef enum
{
	kIndexNested = 0, 		// format for IndexFormat
	kIndexRunIn
} eIndex;

typedef enum
{
	kKernNone = 0, 		// kerning amount for PManualKerning
	kKernCloserFine,
	kKernApartFine,
	kKernCloserCoarse,
	kKernApartCoarse
} eKern;

typedef enum
{
	kKindPublication = 0,
	kKindTemplate,
	kKind50Format
} eKind;

typedef enum
{
	kLeadProportional = 0, 		// leading method for SpacingOptions
	kLeadTopOfCaps,
	kLeadBaseline
} eLead;

enum
{
	kLineNone = 0,		// line style for PLineStyle and PRuleAbove/Below
	kLineHairline,
	kLineHalfPoint,
	kLineOnePoint,
	kLineTwoPoint,
	kLineFourPoint,
	kLineSixPoint,
	kLineEightPoint,
	kLineTwelvePoint,
	kLineThinThin,
	kLineThickThin,
	kLineThinThick,
	kLineThinThickThin,
	kLineThinDash,
	kLineTediumDash,
	kLineThickDash,
	kLineSquares,
	kLineDots,
	kLineSolid = 31
};

typedef enum
{
	kMeasurementInches = 0,		// measurement unit preferences
	kMeasurementDecimalInches,
	kMeasurementMetric,
	kMeasurementPica,
	kMeasurementCicero,
	kMeasurementCustom
} eMeasurement;

typedef enum
{
	kNewPagesBefore = 0,		// insertion location for cWhere
	kNewPagesAfter,
	kNewPagesBetween
} eNewPages;

typedef enum
{
	kNumDontCare		= -2,
	kNumArabic			= 0,		// number types for PageNumbers
	kNumUpperRoman		= 1,
	kNumLowerRoman		= 2,
	kNumUpperAlpha		= 3,
	kNumLowerAlpha		= 4
} eNum;  // :-O

enum
{
	kPageLeftMaster = -3,		// non-numeric page numbers for Page
	kPageRightMaster = -4,
	kPageNext = -5,
	kPagePrevious = -6
} ;

typedef enum
{
	kStylePalette = 1,
	kColorPalette = 2,		
	kControlPalette = 3,
	kMasterPalette = 4
} ePalette;

typedef enum						// for PasteSpecial
{
	kPasteText			= 0,		
	kPasteRTF			= 1,
	kPastEPS			= 2,
	kPasteExternal		= 3,
	kPasteColortronColors	= 4,	// mac only
	kPasteObjectEmbed	= 5,
	kPasteObjectLink	= 6,
	kPastePict			= 7,		// mac only
	kPasteMetafile		= 8,		// mac only
	kPasteTIFF			= 9,		// win only
	kPasteBitmap		= 10,		// win only
	kPasteEnhMetafile	= 11,		// win only
	kPasteDIB			= 12		// win only
} ePaste;

typedef enum
{
	kPlaceIndependent = 0, 		// placement options for Place
	kPlaceNewStory = 0,
	kPlaceReplaceEntire = 1,
	kPlaceInlineGraphic = 1,
	kPlaceInsertText = 2,
	kPlaceReplaceText = 2		// ???
} ePlace;

typedef enum
{
	kPositionNormal = 0, 		// type position for Position
	kPositionSuperscript,
	kPositionSubscript
} ePosition;

typedef enum
{
	kPreserveLine = 0,			// hints for PFontDrawing
	kPreserveChar = 1
} ePreserve;

typedef enum
{
	kPSMemoryNormal = kParmNormal,
	kPSMemoryMaximum = 1
} ePSMemory;

typedef enum
{
	kRenderClipIn = 0,		// settings for RenderClip command
	kRenderClipOut = 1
} eRenderClip;

typedef enum
{
	kSaveFaster = 0, 		// save option for Preferences
	kSaveSmaller = 1
} eSave;

typedef enum
{
	kInkNDDefault = 0,		// ink ND in ink setup dialog
	kInkNDSet = 1
} eInkND;

typedef enum
{
	kStyleNormal = 0, 		// TypeStyles
	kStyleBold,
	kStyleItalic,
	kStyleUnderline,
	kStyleOutline,
	kStyleShadow,
	kStyleStrikethru,
	kStyleReverse
} eStyle;

typedef enum
{
	kTextAmtCharFor = 0, 		// amount for TextSelect and TextCursor
	kTextAmtCharBack,
	kTextAmtWordFor,
	kTextAmtWordBack,
	kTextAmtLineFor,
	kTextAmtLineBack,
	kTextAmtParaFor,
	kTextAmtParaBack,
	kTextAmtHoleFor,
	kTextAmtHoleBack,
	kTextAmtStoryFor,
	kTextAmtStoryBack,
	kTextAmtEolFor,
	kTextAmtEolBack,
	kTextAmtSentFor,
	kTextAmtSentBack,
	kTextAmtRunFor,
	kTextAmtRunBack,
	kTextAmtAll
} eTextAmt;

typedef enum
{
	kTOCNoPageNums = 0, 		// format for CreateTOC
	kTOCPageNumsBefore,
	kTOCPageNumsAfter
} eTOC;

typedef enum					// used by PTool and PGetTool
{
	kPointerTool = 1,
	kTextTool, 
	kOvalTool, 
	kRoundedRectTool, 
	kDiagLineTool, 
	kPerpLineTool,
	kPolygonTool,
	kZoomTool,
	kRotationTool, 
	kCropTool 
} eTool;

typedef enum
{
	kTrackNoTrack = 0, 			// kerning track for PTrack, PGetTrack
	kTrackVeryLoose,
	kTrackLoose,
	kTrackNormal,
	kTrackTight,
	kTrackVeryTight
	// kTrackMultiple = -2		// may be returned by PGetTrack
} eTrack;

typedef enum
{
	kViewFitToWindow = -3,		// non-percentage choices for View
	kViewPasteboard = -4
} eView;

typedef enum
{
	kWrapNone = 0, 		// wrap option for TextWrap
	kWrapRect = 1,
	kWrapIrregular = 2,
	kWrapCustom = 2 		// duplicate, should be removed someday
} eWrap;


#endif

// end of PKeywords.h
